startIconSplashColor property

Color? startIconSplashColor
final

The splash color of the start icon. The splash color is the color that appears when the icon is tapped. By default is null, because it is calculated automatically by the Material widget.

Implementation

final Color? startIconSplashColor;